@@ -1,4 +1,4 @@
-package LedgerSMB::Installer::OS::linux v0.999.6;
+package LedgerSMB::Installer::OS::linux v0.999.7;
 
 use v5.20;
 use experimental qw(signatures);
@@ -41,14 +41,6 @@ sub cleanup_env($self, $config, %args) {
     warn $log->fatal('generic linux support does not include package manager support');
 }
 
-sub prepare_builder_env($self, $config) {
-    warn $log->warning('generic linux support does not allow creating build environment');
-}
-
-sub prepare_builder_env($self, $config) {
-    warn $log->warning('generic linux support does not allow creating install environment');
-}
-
 sub prepare_pkg_resolver_env($self, $config) {
     warn $log->warning('generic linux support does not allow creating module-to-package mapping environment');
 }
